.. PyRoombaAdapter documentation master file, created by
   sphinx-quickstart on Thu Aug 15 13:03:38 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   API
   GitHub <https://github.com/AtsushiSakai/PyRoombaAdapter/>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
